@@ -3,7 +3,7 @@ from localstack.services.infra import start_moto_server
 
 
 def start_rgsa(port=None, asynchronous=False, update_listener=None):
-    port = port or config.PORT_RESOURCEGROUPSTAGGINGAPI
+    port = port or config.service_port("resourcegroupstaggingapi")
 
     return start_moto_server(
         "resourcegroupstaggingapi",
