@@ -11,7 +11,6 @@ from typing import Dict, List
 from urllib.parse import parse_qs, urlparse
 
 import requests
-import six
 import xmltodict
 from flask import Response as FlaskResponse
 from moto.sns.exceptions import DuplicateSnsEndpointError
@@ -22,7 +21,6 @@ from localstack.config import external_service_url
 from localstack.constants import MOTO_ACCOUNT_ID, TEST_AWS_ACCOUNT_ID
 from localstack.services.awslambda import lambda_api
 from localstack.services.generic_proxy import RegionBackend
-from localstack.services.install import SQS_BACKEND_IMPL
 from localstack.utils.analytics import event_publisher
 from localstack.utils.aws import aws_stack
 from localstack.utils.aws.aws_responses import (
@@ -235,7 +233,34 @@ class ProxyListenerSNS(PersistingProxyListener):
                 return make_response(req_action, message_id=message_id)
 
             elif req_action == "PublishBatch":
-                response = publish_batch(topic_arn, req_data, headers)
+                entries = parse_urlencoded_data(
+                    req_data, "PublishBatchRequestEntries.member", "MessageAttributes.entry"
+                )
+
+                if len(entries) > 10:
+                    return make_error(
+                        message="The batch request contains more entries than permissible",
+                        code=400,
+                        code_string="TooManyEntriesInBatchRequest",
+                    )
+                ids = [entry["Id"] for entry in entries]
+
+                if len(set(ids)) != len(entries):
+                    return make_error(
+                        message="Two or more batch entries in the request have the same Id",
+                        code=400,
+                        code_string="BatchEntryIdsNotDistinct",
+                    )
+
+                if topic_arn and ".fifo" in topic_arn:
+                    if not all(["MessageGroupId" in entry for entry in entries]):
+                        return make_error(
+                            message="The MessageGroupId parameter is required for FIFO topics",
+                            code=400,
+                            code_string="InvalidParameter",
+                        )
+
+                response = publish_batch(topic_arn, entries, headers)
                 return requests_response_xml(
                     req_action, response, xmlns="http://sns.amazonaws.com/doc/2010-03-31/"
                 )
@@ -511,14 +536,20 @@ async def message_to_subscriber(
                 req_data.get("MessageGroupId")[0] if req_data.get("MessageGroupId") else ""
             )
 
+            message_deduplication_id = (
+                req_data.get("MessageDeduplicationId")[0]
+                if req_data.get("MessageDeduplicationId")
+                else ""
+            )
+
             sqs_client = aws_stack.connect_to_service("sqs")
 
-            # TODO remove this kwargs if we stop using ElasticMQ entirely
-            kwargs = (
-                {"MessageGroupId": message_group_id}
-                if message_group_id and SQS_BACKEND_IMPL == "moto"
-                else {}
-            )
+            kwargs = {}
+            if message_group_id:
+                kwargs["MessageGroupId"] = message_group_id
+            if message_deduplication_id:
+                kwargs["MessageDeduplicationId"] = message_deduplication_id
+
             sqs_client.send_message(
                 QueueUrl=queue_url,
                 MessageBody=create_sns_message_body(subscriber, req_data, message_id),
@@ -604,7 +635,7 @@ async def message_to_subscriber(
 
             delivery = {
                 "statusCode": response.status_code,
-                "providerResponse": response.get_data(),
+                "providerResponse": response.content.decode("utf-8"),
             }
             store_delivery_log(subscriber, True, message, message_id, delivery)
 
@@ -686,17 +717,17 @@ def publish_message(topic_arn, req_data, headers, subscription_arn=None, skip_ch
     return message_id
 
 
-def publish_batch(topic_arn, req_data, headers):
+def publish_batch(topic_arn, messages, headers):
     response = {"Successful": [], "Failed": []}
-    messages = parse_urlencoded_data(
-        req_data, "PublishBatchRequestEntries.member", "MessageAttributes.entry"
-    )
     for message in messages:
         message_id = str(uuid.uuid4())
         data = {}
         data["TopicArn"] = [topic_arn]
         data["Message"] = [message["Message"]]
-        data["Subject"] = [message["Subject"]]
+        data["Subject"] = [message.get("Subject")]
+        if ".fifo" in topic_arn:
+            data["MessageGroupId"] = message.get("MessageGroupId")
+        # TODO: add MessageDeduplication checks once ASF-SQS implementation becomes default
 
         message_attributes = prepare_message_attributes(message.get("MessageAttributes", []))
         try:
@@ -875,10 +906,6 @@ def create_sns_message_body(subscriber, req_data, message_id=None):
     message = req_data["Message"][0]
     protocol = subscriber["Protocol"]
 
-    if six.PY2 and type(message).__name__ == "unicode":
-        # fix non-ascii unicode characters under Python 2
-        message = message.encode("raw-unicode-escape")
-
     if req_data.get("MessageStructure") == ["json"]:
         message = json.loads(message)
         try:
